@@ -590,22 +590,44 @@ class TDeviceWin(TDeviceBase) :
         return this.__Api.TDeviceAgingMeasureADCResultStructureByteSize()
             
     def ANA670X_GetChipIDCount(this) : 
-        return 1  #ted.ANA670X_GetChipIDCount()
+        return this.__Api.TDeviceANA670X_GetChipIDCount(this.__DeviceHandle)
 
     def ANA670X_GetChipID(this, dutIdx) : 
-        return 1 #ted.ANA670X_GetChipID(dutIdx)
+        chiIdCount = this.ANA670X_GetChipIDCount()
+        chipIdList = [0 for _ in range(chiIdCount)]
+        chipIdByteArray = bytes(chiIdCount)
+        ret = this.__Api.TDeviceANA670X_GetChipID(this.__DeviceHandle, dutIdx, chipIdByteArray)
+        if ret==1 :
+            for idx, regValueByte in enumerate(chipIdByteArray) :
+                regValueInt = regValueByte
+                regValueInt &= 0xFF
+                chipIdList[idx] = regValueInt
+        
+        return chipIdList
 
     def ANA670X_GetProductRevisionBytesCount(this) : 
-        return 1 #ted.ANA670X_GetProductRevisionBytesCount()
+        return this.__Api.TDeviceANA670X_GetProductRevisionBytesCount(this.__DeviceHandle)
 
     def ANA670X_GetProductRevisionBytes(this, dutIdx) : 
-        return 1 #ted.ANA670X_GetProductRevisionBytes(dutIdx)
+        
+        revCount = this.ANA670X_GetProductRevisionBytesCount()
+        revList = [0 for _ in range(revCount)]
+        revByteArray = bytes(revCount)
+        ret = this.__Api.TDeviceANA670X_GetProductRevisionBytes(this.__DeviceHandle, dutIdx, revByteArray)
+        if ret==1 :
+            for idx, regValueByte in enumerate(revByteArray) :
+                regValueInt = regValueByte
+                regValueInt &= 0xFF
+                revList[idx] = regValueInt
+        
+        return revList
+
 
     def ANA670X_SetFrameRate(this, dutIdx, fr) :
-        return True #ted.ANA670X_SetFrameRate(dutIdx, fr)
+        return this.__Api.TDeviceANA670X_SetFrameRate(this.__DeviceHandle, dutIdx)
 
     def ANA670X_GetFrameRate(this, dutIdx) : 
-        return 1 #ted.ANA670X_GetFrameRate(dutIdx)
+        return this.__Api.TDeviceANA670X_GetFrameRate(this.__DeviceHandle, dutIdx)
 
     #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value)
     def AdcSoutSetRBSel(this, dutIdx, value) :
@@ -854,6 +876,127 @@ class TDeviceWin(TDeviceBase) :
     def SysMipiIsLock(this) : 
         return this.__Api.TDeviceSysMipiIsLock(this.__DeviceHandle)
 
+    #COMM_API int TedAdcGetInvalidValue();
+    def AdcGetInvalidValue(this) : 
+        return this.__Api.TDeviceAdcGetInvalidValue(this.__DeviceHandle)
+
+    #COMM_API int TedAdcGetGroupCount(int dutIdx);
+    def AdcGetGroupCount(this, dutIdx) : 
+        return this.__Api.TDeviceAdcGetGroupCount(this.__DeviceHandle, dutIdx)
+
+    #COMM_API Bool TedAdcGetGroupName(int dutIdx, int groupIdx, char* szGroupName);
+    def AdcGetGroupName(this, dutIdx, grpIdx) : 
+        grpNameBytes=bytes(256)
+        this.__Api.TDeviceAdcGetGroupName(this.__DeviceHandle, dutIdx, grpIdx, grpNameBytes)
+        return TString.CStrToPyStr(grpNameBytes)
+
+    #COMM_API int TedAdcGetGroupIndexByName(int dutIdx, const char* groupName);
+    def AdcGetGroupIndexByName(this, dutIdx, grpName) : 
+        return this.__Api.TDeviceAdcGetGroupIndexByName(this.__DeviceHandle, dutIdx, TString.ConvertToCTypeStrng(grpName))
+
+    #COMM_API int TedAdcGetChannelCount(int dutIdx, int groupIdx);
+    def AdcGetChannelCount(this, dutIdx, grpIdx) : 
+        return this.__Api.TDeviceAdcGetChannelCount(this.__DeviceHandle, dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcGetChannelName(int dutIdx, int groupIdx, int chIdx, /*OUT*/ char* szChName);
+    def AdcGetChannelName(this, dutIdx, grpIdx, chIdx) : 
+        chNameBytes=bytes(256)
+        this.__Api.TDeviceAdcGetChannelName(this.__DeviceHandle, dutIdx, grpIdx, chIdx, chNameBytes)
+        return TString.CStrToPyStr(chNameBytes)
+
+    #COMM_API int TedAdcGetGroupIndexByPsID(int dutIdx, int psID);
+    def AdcGetGroupIndexByPsID(this, dutIdx, psID) : 
+        return this.__Api.TDeviceAdcGetGroupIndexByPsID(this.__DeviceHandle, dutIdx, psID)
+
+    #COMM_API int TedAdcGetChannelIndexByPsID(int dutIdx, int psID);
+    def AdcGetChannelIndexByPsID(this, dutIdx, psID) : 
+        return this.__Api.TDeviceAdcGetChannelIndexByPsID(this.__DeviceHandle, dutIdx, psID)
+
+    #COMM_API Bool TedAdcSetDevConfig(int dutIdx, int groupIdx, int value);
+    def AdcSetDevConfig(this, dutIdx, grpIdx, value) :
+        return this.__Api.TDeviceAdcSetDevConfig(this.__DeviceHandle, dutIdx, grpIdx, value)
+
+    #COMM_API int TedAdcGetDevConfig(int dutIdx, int groupIdx);
+    def AdcGetDevConfig(this, dutIdx, grpIdx) :
+        return this.__Api.TDeviceAdcGetDevConfig(this.__DeviceHandle, dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcSetInConfig(int dutIdx, int groupIdx, int chIdx, int value);
+    def AdcSetInConfig(this, dutIdx, grpIdx, value) :
+        return this.__Api.TDeviceAdcSetInConfig(this.__DeviceHandle, dutIdx, grpIdx, value)
+
+    #COMM_API int TedAdcGetInConfig(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetInConfig(this, dutIdx, grpIdx, chIdx) :
+        return this.__Api.TDeviceAdcGetInConfig(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetVoltage(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) :
+        return this.__Api.TDeviceAdcGetVoltage(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
+    def AdcGetVoltageByPsID(this, dutIdx, psID) :
+        return this.__Api.TDeviceAdcGetVoltageByPsID(this.__DeviceHandle, dutIdx, psID)
+
+    #COMM_API float TedAdcGetVoltFloatByPsID(int dutIdx, int psID);
+    def AdcGetVoltFloatByPsID(this, dutIdx, psID) :
+        return this.__Api.TDeviceAdcGetVoltFloatByPsID(this.__DeviceHandle, dutIdx, psID)
+
+    #COMM_API Bool TedAdcGetAllVoltage(int dutIdx, int groupIdx, int* valueArray);
+    def AdcGetAllVoltage(this, dutIdx, grpIdx) :
+
+        chCnt = this.AdcGetChannelCount(dutIdx, grpIdx)
+        adcList = [0 for _ in range(chCnt)]
+        
+        structFmt = "%di" % chCnt
+        #adcValueArrayBytes = struct.pack(structFmt, [0 for _ in range(chCnt)] )
+        #adcValueArrayBytes = struct.pack(structFmt, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
+
+        adcValueArrayBytes = bytes(chCnt*4)
+        
+        this.__Api.TDeviceAdcGetAllVoltage(this.__DeviceHandle, dutIdx, grpIdx, adcValueArrayBytes)
+
+        result= struct.unpack(structFmt, adcValueArrayBytes)
+
+        for i in range(chCnt) :
+            adcList[i] = result[i]
+
+        #adcList = [0 for _ in range(chCnt)]
+        #adcValueArrayBytes = bytes(chCnt*4)
+        #this.__Api.TDeviceAdcGetAllVoltage(dutIdx, grpIdx, adcValueArrayBytes)
+        
+        #adcInt = 0
+        #for idx, value in enumerate(adcValueArrayBytes) :
+        #    if (idx+1) % 4 == 0 : 
+        #        adcList[idx/4] = adcInt
+        #    else :
+        #        adcInt |= value << (8*idx)
+
+        return adcList
+
+
+    #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) :
+        return this.__Api.TDeviceAdcGetCurrent(dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
+    def AdcGetCurrentByPsID(this, dutIdx, psID) :
+        return this.__Api.TDeviceAdcGetCurrentByPsID(dutIdx, psID)
+
+    #COMM_API float TedAdcGetCurrFloatByPsID(int dutIdx, int psID);
+    def AdcGetCurrFloatByPsID(this, dutIdx, psID) :
+        return this.__Api.TDeviceAdcGetCurrFloatByPsID(dutIdx, psID)
+
+    #COMM_API Bool TedAdcGetAllCurrent(int dutIdx, int groupIdx, int* valueArray);
+    def AdcGetAllCurrent(this, dutIdx, grpIdx) :
+        return this.__Api.TDeviceAdcGetAllCurrent(dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
+    def AdcSoutSetRBSel(this, dutIdx, value) :
+        return this.__Api.TDeviceAdcSoutSetRBSel(dutIdx, value)
+
+    #COMM_API int TedAdcSoutGetRBSel(int dutIdx);
+    def AdcSoutGetRBSel(this, dutIdx) :
+        return this.__Api.TDeviceAdcSoutGetRBSel(dutIdx)
+
 
 #
 # class TFileTransfer
