@@ -269,6 +269,118 @@ class Api :
         this.TDeviceDD_FB_blank.restype=c_int;
         this.TDeviceDD_FB_blank.argtypes=[c_void_p, c_int, c_int]
 
+
+        #TDEVICE_API int TDeviceAdcGetInvalidValue(void* hdl);
+        this.TDeviceAdcGetInvalidValue = Load_DLL['TDeviceAdcGetInvalidValue']
+        this.TDeviceAdcGetInvalidValue.restype=c_int;
+        this.TDeviceAdcGetInvalidValue.argtypes=[c_void_p]
+
+        #TDEVICE_API int TDeviceAdcGetGroupCount(void* hdl, int dutIdx);
+        this.TDeviceAdcGetGroupCount = Load_DLL['TDeviceAdcGetGroupCount']
+        this.TDeviceAdcGetGroupCount.restype=c_int;
+        this.TDeviceAdcGetGroupCount.argtypes=[c_void_p, c_int]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcGetGroupName(void* hdl, int dutIdx, int groupIdx, char* szGroupName);
+        this.TDeviceAdcGetGroupName = Load_DLL['TDeviceAdcGetGroupName']
+        this.TDeviceAdcGetGroupName.restype=c_int;
+        this.TDeviceAdcGetGroupName.argtypes=[c_void_p, c_int, c_int, c_char_p]
+
+        #TDEVICE_API int TDeviceAdcGetGroupIndexByName(void* hdl, int dutIdx, const char* groupName);
+        this.TDeviceAdcGetGroupIndexByName = Load_DLL['TDeviceAdcGetGroupIndexByName']
+        this.TDeviceAdcGetGroupIndexByName.restype=c_int;
+        this.TDeviceAdcGetGroupIndexByName.argtypes=[c_void_p, c_int, c_char_p]
+
+        #TDEVICE_API int TDeviceAdcGetChannelCount(void* hdl, int dutIdx, int groupIdx);
+        this.TDeviceAdcGetChannelCount = Load_DLL['TDeviceAdcGetChannelCount']
+        this.TDeviceAdcGetChannelCount.restype=c_int;
+        this.TDeviceAdcGetChannelCount.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcGetChannelName(void* hdl, int dutIdx, int groupIdx, int chIdx, /*OUT*/ char* szChName);
+        this.TDeviceAdcGetChannelName = Load_DLL['TDeviceAdcGetChannelName']
+        this.TDeviceAdcGetChannelName.restype=c_int;
+        this.TDeviceAdcGetChannelName.argtypes=[c_void_p, c_int, c_int, c_int, c_char_p]
+
+        #TDEVICE_API int TDeviceAdcGetGroupIndexByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetGroupIndexByPsID = Load_DLL['TDeviceAdcGetGroupIndexByPsID']
+        this.TDeviceAdcGetGroupIndexByPsID.restype=c_int;
+        this.TDeviceAdcGetGroupIndexByPsID.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API int TDeviceAdcGetChannelIndexByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetChannelIndexByPsID = Load_DLL['TDeviceAdcGetChannelIndexByPsID']
+        this.TDeviceAdcGetChannelIndexByPsID.restype=c_int;
+        this.TDeviceAdcGetChannelIndexByPsID.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcSetDevConfig(void* hdl, int dutIdx, int groupIdx, int value);
+        this.TDeviceAdcSetDevConfig = Load_DLL['TDeviceAdcSetDevConfig']
+        this.TDeviceAdcSetDevConfig.restype=c_int;
+        this.TDeviceAdcSetDevConfig.argtypes=[c_void_p, c_int, c_int, c_int]
+
+        #TDEVICE_API int TDeviceAdcGetDevConfig(void* hdl, int dutIdx, int groupIdx);
+        this.TDeviceAdcGetDevConfig = Load_DLL['TDeviceAdcGetDevConfig']
+        this.TDeviceAdcGetDevConfig.restype=c_int;
+        this.TDeviceAdcGetDevConfig.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcSetInConfig(void* hdl, int dutIdx, int groupIdx, int chIdx, int value);
+        this.TDeviceAdcSetInConfig = Load_DLL['TDeviceAdcSetInConfig']
+        this.TDeviceAdcSetInConfig.restype=c_int;
+        this.TDeviceAdcSetInConfig.argtypes=[c_void_p, c_int, c_int, c_int, c_int]
+
+        #TDEVICE_API int TDeviceAdcGetInConfig(void* hdl, int dutIdx, int groupIdx, int chIdx);
+        this.TDeviceAdcGetInConfig = Load_DLL['TDeviceAdcGetInConfig']
+        this.TDeviceAdcGetInConfig.restype=c_int;
+        this.TDeviceAdcGetInConfig.argtypes=[c_void_p, c_int, c_int, c_int]
+
+        #TDEVICE_API int TDeviceAdcGetVoltage(void* hdl, int dutIdx, int groupIdx, int chIdx);
+        this.TDeviceAdcGetVoltage = Load_DLL['TDeviceAdcGetVoltage']
+        this.TDeviceAdcGetVoltage.restype=c_int;
+        this.TDeviceAdcGetVoltage.argtypes=[c_void_p, c_int, c_int, c_int]
+
+        #TDEVICE_API int TDeviceAdcGetVoltageByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetVoltageByPsID = Load_DLL['TDeviceAdcGetVoltageByPsID']
+        this.TDeviceAdcGetVoltageByPsID.restype=c_int;
+        this.TDeviceAdcGetVoltageByPsID.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API float TDeviceAdcGetVoltFloatByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetVoltFloatByPsID = Load_DLL['TDeviceAdcGetVoltFloatByPsID']
+        this.TDeviceAdcGetVoltFloatByPsID.restype=c_int;
+        this.TDeviceAdcGetVoltFloatByPsID.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcGetAllVoltage(void* hdl, int dutIdx, int groupIdx, int* valueArray);
+        this.TDeviceAdcGetAllVoltage = Load_DLL['TDeviceAdcGetAllVoltage']
+        this.TDeviceAdcGetAllVoltage.restype=c_int;
+        this.TDeviceAdcGetAllVoltage.argtypes=[c_void_p, c_int, c_int, c_char_p]
+
+        #TDEVICE_API int TDeviceAdcGetCurrent(void* hdl, int dutIdx, int groupIdx, int chIdx);
+        this.TDeviceAdcGetCurrent = Load_DLL['TDeviceAdcGetCurrent']
+        this.TDeviceAdcGetCurrent.restype=c_int;
+        this.TDeviceAdcGetCurrent.argtypes=[c_void_p, c_int, c_int, c_char_p]
+        
+        #TDEVICE_API int TDeviceAdcGetCurrentByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetCurrentByPsID = Load_DLL['TDeviceAdcGetCurrentByPsID']
+        this.TDeviceAdcGetCurrentByPsID.restype=c_int;
+        this.TDeviceAdcGetCurrentByPsID.argtypes=[c_void_p, c_int, c_int]
+
+        #TDEVICE_API float TDeviceAdcGetCurrFloatByPsID(void* hdl, int dutIdx, int psID);
+        this.TDeviceAdcGetCurrFloatByPsID = Load_DLL['TDeviceAdcGetCurrFloatByPsID']
+        this.TDeviceAdcGetCurrFloatByPsID.restype=c_int;
+        this.TDeviceAdcGetCurrFloatByPsID.argtypes=[c_void_p, c_int, c_int]
+    
+        #TDEVICE_API TED_BOOL TDeviceAdcGetAllCurrent(void* hdl, int dutIdx, int groupIdx, int* valueArray);
+        this.TDeviceAdcGetAllCurrent = Load_DLL['TDeviceAdcGetAllCurrent']
+        this.TDeviceAdcGetAllCurrent.restype=c_int;
+        this.TDeviceAdcGetAllCurrent.argtypes=[c_void_p, c_int, c_int, c_char_p]
+    
+        #TDEVICE_API TED_BOOL TDeviceAdcSoutSetRBSel(void* hdl, int dutIdx, int value);
+        this.TDeviceAdcSoutSetRBSel = Load_DLL['TDeviceAdcSoutSetRBSel']
+        this.TDeviceAdcSoutSetRBSel.restype=c_int;
+        this.TDeviceAdcSoutSetRBSel.argtypes=[c_void_p, c_int, c_int]
+    
+        #TDEVICE_API int TDeviceAdcSoutGetRBSel(void* hdl, int dutIdx);
+        this.TDeviceAdcSoutGetRBSel = Load_DLL['TDeviceAdcSoutGetRBSel']
+        this.TDeviceAdcSoutGetRBSel.restype=c_int;
+        this.TDeviceAdcSoutGetRBSel.argtypes=[c_void_p, c_int]
+    
+
         #//VLIN1_ADC
         #TDEVICE_API TED_BOOL TDeviceVlin1AdcSetSamples(TDEVICE_HDL hdl, int dutIdx, int value);  
         this.TDeviceVlin1AdcSetSamples = Load_DLL['TDeviceVlin1AdcSetSamples']
@@ -515,6 +627,35 @@ class Api :
         this.TDeviceAgingMeasureADCResultStructureByteSize.restype=c_int;
         this.TDeviceAgingMeasureADCResultStructureByteSize.argtypes=[c_void_p]
 
+        #TDEVICE_API int TDeviceANA670X_GetChipIDCount(void* hdl);
+        this.TDeviceANA670X_GetChipIDCount = Load_DLL['TDeviceANA670X_GetChipIDCount']
+        this.TDeviceANA670X_GetChipIDCount.restype=c_int;
+        this.TDeviceANA670X_GetChipIDCount.argtypes=[c_void_p]
+
+        #TDEVICE_API TED_BOOL TDeviceANA670X_GetChipID(void* hdl, int dutIdx, /*OUT*/unsigned char* chipIDArr);
+        this.TDeviceANA670X_GetChipID = Load_DLL['TDeviceANA670X_GetChipID']
+        this.TDeviceANA670X_GetChipID.restype=c_int;
+        this.TDeviceANA670X_GetChipID.argtypes=[c_void_p, c_int, c_char_p]
+
+        #TDEVICE_API TED_BOOL TDeviceANA670X_SetFrameRate(void* hdl, int dutIdx, int fr);
+        this.TDeviceANA670X_SetFrameRate = Load_DLL['TDeviceANA670X_SetFrameRate']
+        this.TDeviceANA670X_SetFrameRate.restype=c_int;
+        this.TDeviceANA670X_SetFrameRate.argtypes=[c_void_p, c_int , c_int]
+
+        #TDEVICE_API int TDeviceANA670X_GetFrameRate(void* hdl, int dutIdx);
+        this.TDeviceANA670X_GetFrameRate = Load_DLL['TDeviceANA670X_GetFrameRate']
+        this.TDeviceANA670X_GetFrameRate.restype=c_int;
+        this.TDeviceANA670X_GetFrameRate.argtypes=[c_void_p, c_int]
+
+        #TDEVICE_API int TDeviceANA670X_GetProductRevisionBytesCount(void* hdl);
+        this.TDeviceANA670X_GetProductRevisionBytesCount = Load_DLL['TDeviceANA670X_GetProductRevisionBytesCount']
+        this.TDeviceANA670X_GetProductRevisionBytesCount.restype=c_int;
+        this.TDeviceANA670X_GetProductRevisionBytesCount.argtypes=[c_void_p]
+
+        #TDEVICE_API TED_BOOL TDeviceANA670X_GetProductRevisionBytes(void* hdl, int dutIdx, /*OUT*/unsigned char* revArr);
+        this.TDeviceANA670X_GetProductRevisionBytes = Load_DLL['TDeviceANA670X_GetProductRevisionBytes']
+        this.TDeviceANA670X_GetProductRevisionBytes.restype=c_int;
+        this.TDeviceANA670X_GetProductRevisionBytes.argtypes=[c_void_p, c_int, c_char_p]
 
         # enum TFileTransferType {
         #    TFileTransferTypeT5 = 0,
