@@ -429,6 +429,93 @@ class TDevice :
     def GetAgingMeasureADCCount(this) :
         return this.__AgingMeasureAdcCount
 
+    #COMM_API int TedAdcGetInvalidValue();
+    def AdcGetInvalidValue(this) : 
+        return this.__TDevice.AdcGetInvalidValue()
+
+    #COMM_API int TedAdcGetGroupCount(int dutIdx);
+    def AdcGetGroupCount(this, dutIdx) : 
+        return this.__TDevice.AdcGetGroupCount(dutIdx)
+
+    #COMM_API Bool TedAdcGetGroupName(int dutIdx, int groupIdx, char* szGroupName);
+    def AdcGetGroupName(this, dutIdx, grpIdx) : 
+        return this.__TDevice.AdcGetGroupName(dutIdx, grpIdx)
+
+    #COMM_API int TedAdcGetGroupIndexByName(int dutIdx, const char* groupName);
+    def AdcGetGroupIndexByName(this, dutIdx, grpName) : 
+        return this.__TDevice.AdcGetGroupIndexByName(dutIdx, grpName)
+
+    #COMM_API int TedAdcGetChannelCount(int dutIdx, int groupIdx);
+    def AdcGetChannelCount(this, dutIdx, grpIdx) : 
+        return this.__TDevice.AdcGetChannelCount(dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcGetChannelName(int dutIdx, int groupIdx, int chIdx, /*OUT*/ char* szChName);
+    def AdcGetChannelName(this, dutIdx, grpIdx, chIdx) : 
+        return this.__TDevice.AdcGetChannelName(dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetGroupIndexByPsID(int dutIdx, int psID);
+    def AdcGetGroupIndexByPsID(this, dutIdx, psID) : 
+        return this.__TDevice.AdcGetGroupIndexByPsID(dutIdx, psID)
+
+    #COMM_API int TedAdcGetChannelIndexByPsID(int dutIdx, int psID);
+    def AdcGetChannelIndexByPsID(this, dutIdx, psID) : 
+        return this.__TDevice.AdcGetChannelIndexByPsID(dutIdx, psID)
+
+    #COMM_API Bool TedAdcSetDevConfig(int dutIdx, int groupIdx, int value);
+    def AdcSetDevConfig(this, dutIdx, grpIdx, value) : 
+        return this.__TDevice.AdcSetDevConfig(dutIdx, grpIdx, value)
+
+    #COMM_API int TedAdcGetDevConfig(int dutIdx, int groupIdx);
+    def AdcGetDevConfig(this, dutIdx, grpIdx) : 
+        return this.__TDevice.AdcGetDevConfig(dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcSetInConfig(int dutIdx, int groupIdx, int chIdx, int value);
+    def AdcSetInConfig(this, dutIdx, grpIdx, value) :
+        return this.__TDevice.AdcSetInConfig(dutIdx, grpIdx, value)
+
+    #COMM_API int TedAdcGetInConfig(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetInConfig(this, dutIdx, grpIdx, chIdx) :
+        return this.__TDevice.AdcGetInConfig(dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetVoltage(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) :
+        return this.__TDevice.AdcGetVoltage(dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
+    def AdcGetVoltageByPsID(this, dutIdx, psID) :
+        return this.__TDevice.AdcGetVoltageByPsID(dutIdx, psID)
+
+    #COMM_API float TedAdcGetVoltFloatByPsID(int dutIdx, int psID);
+    def AdcGetVoltFloatByPsID(this, dutIdx, psID) :
+        return this.__TDevice.AdcGetVoltFloatByPsID(dutIdx, psID)
+
+    #COMM_API Bool TedAdcGetAllVoltage(int dutIdx, int groupIdx, int* valueArray);
+    def AdcGetAllVoltage(this, dutIdx, grpIdx) :
+        return this.__TDevice.AdcGetAllVoltage(dutIdx, grpIdx)
+
+    #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
+    def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) :
+        return this.__TDevice.AdcGetCurrent(dutIdx, grpIdx, chIdx)
+
+    #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
+    def AdcGetCurrentByPsID(this, dutIdx, psID) :
+        return this.__TDevice.AdcGetCurrentByPsID(dutIdx, psID)
+
+    #COMM_API float TedAdcGetCurrFloatByPsID(int dutIdx, int psID);
+    def AdcGetCurrFloatByPsID(this, dutIdx, psID) :
+        return this.__TDevice.AdcGetCurrFloatByPsID(dutIdx, psID)
+
+    #COMM_API Bool TedAdcGetAllCurrent(int dutIdx, int groupIdx, int* valueArray);
+    def AdcGetAllCurrent(this, dutIdx, grpIdx) :
+        return this.__TDevice.AdcGetAllCurrent(dutIdx, grpIdx)
+
+    #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
+    def AdcSoutSetRBSel(this, dutIdx, value) :
+        return this.__TDevice.AdcSoutSetRBSel(dutIdx, value)
+
+    #COMM_API int TedAdcSoutGetRBSel(int dutIdx);
+    def AdcSoutGetRBSel(this, dutIdx) :
+        return this.__TDevice.AdcSoutGetRBSel(dutIdx)
 
 
 
